# aioazuredevops

[![GitHub Release][releases-shield]][releases]
![Project Stage][project-stage-shield]
[![License][license-shield]](LICENSE.md)

[![Buy me a coffee][buymeacoffee-shield]][buymeacoffee]

Get data from the Azure DevOps API using aiohttp.

## Links

[Contribution Guidelines][CONTRIBUTING]

[Code of Conduct][CODE_OF_CONDUCT]

[buymeacoffee-shield]: https://www.buymeacoffee.com/assets/img/guidelines/download-assets-sm-2.svg
[buymeacoffee]: https://www.buymeacoffee.com/timmo
[CODE_OF_CONDUCT]: https://github.com/timmo001/aioazuredevops/blob/master/.github/CODE_OF_CONDUCT.md
[CONTRIBUTING]: https://github.com/timmo001/aioazuredevops/blob/master/.github/CONTRIBUTING.md
[license-shield]: https://img.shields.io/github/license/timmo001/aioazuredevops.svg
[project-stage-shield]: https://img.shields.io/badge/project%20stage-beta-blue.svg
[pulls-shield]: https://img.shields.io/docker/pulls/timmo001/aioazuredevops.svg
[releases-shield]: https://img.shields.io/github/release/timmo001/aioazuredevops.svg
[releases]: https://github.com/timmo001/aioazuredevops/releases
